Document

Struct Document 

pub struct Document<'a, 'b> {
    pub client: &'a Client,
    pub service_sid: &'b str,
    pub sid: &'b str,
}

Fields

client: &'a Clientservice_sid: &'b strsid: &'b str

SID of the Sync Document. Can also be the friendly name.

Implementations

Source

impl Document<'_, '_>

pub async fn get(&self) -> Result<SyncDocument, TwilioError>

Gets a Sync Document

Targets the Sync Service provided to the service() argument and fetches the Document provided to the document() argument.

pub async fn update<T>( &self, params: UpdateParams<'_, T>, ) -> Result<SyncDocument, TwilioError>
where T: ?Sized + Serialize,

Update a Sync Document

Targets the Sync Service provided to the service() argument and updates the Document provided to the document() argument.

pub async fn delete(&self) -> Result<(), TwilioError>

Deletes a Sync Service

Targets the Sync Service provided to the service() argument and deletes the Document provided to the document() argument.