Map

Struct Map 

pub struct Map<'a, 'b> {
    pub client: &'a Client,
    pub service_sid: &'b str,
    pub sid: &'b str,
}

Fields

client: &'a Clientservice_sid: &'b strsid: &'b str

SID of the Sync Map. Can also be it’s unique name.

Implementations

Source

impl<'b> Map<'_, 'b>

pub async fn get(&self) -> Result<SyncMap, TwilioError>

Gets a Sync Map

Targets the Sync Service provided to the service() argument and fetches the Map provided to the map() argument.

pub async fn update(&self, params: UpdateParams) -> Result<SyncMap, TwilioError>

Update a Sync Map

Targets the Sync Service provided to the service() argument and updates the Map provided to the map() argument.

pub async fn delete(&self) -> Result<(), TwilioError>

Deletes a Sync Map

Targets the Sync Service provided to the service() argument and deletes the Map provided to the map() argument.

This will delete any Sync Map items underneath this map.

pub fn mapitem(&self, key: &'b str) -> MapItem<'_, '_>

Functions relating to a known Sync Map Item.

Takes in the key of the Sync Map Item to perform actions against.

pub fn mapitems(&self) -> MapItems<'_, '_>

General Sync Map Item functions.